package writer2latex.rdf;

import java.io.StringWriter;

import javax.xml.transform.OutputKeys;
import javax.xml.transform.Result;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.ls.DOMImplementationLS;
import org.w3c.dom.ls.LSSerializer;

import writer2latex.xhtml.XhtmlDocument;

public class DocumentPart {

	private XhtmlDocument excerptDoc;
	private String path;
	private String itemNumber;
	private String body;
	private String parentPath;
	private String name;
	private String order;

	public DocumentPart(XhtmlDocument document) {
		this.excerptDoc = document;
		extractPath();
		extractName();
		extractNumber();
		extractBody();
		calculateParentPath();
	}
	public DocumentPart(String path) {
		this.path = path;
		this.name = "";
		extractNumber();
		this.body = "";
		calculateParentPath();
	}
	private void extractName() {
		Element excerptContentNode = excerptDoc.getContentNode();
		this.name = excerptContentNode.getAttribute("name");		
	}
	private void extractNumber() {
		itemNumber = path.replaceAll("([0-9]+ )+", "");
	}
	public String getPath() {
		return path;
	}
	public String getSafePath(){
		return path.replaceAll(" ","_");
	}
	public String getNumber() {
		return itemNumber;
	}
	public String getBody() {
		return body;
	}
	public void setOrder(String order) {
		this.order = order;
	}
	public String getOrder() {
		return order;
	}
	public String getParentPath() {
		return parentPath;
	}
	public String getName() {
		if (name.isEmpty()) {
			return "NONAME";
		}
		return name;
	}
	
	private void extractPath() {
		Element excerptContentNode = excerptDoc.getContentNode();
		this.path = excerptContentNode.getAttribute("path");
	}
	
	private void calculateParentPath() {
		if(path.length() == 1) {
			parentPath = "";
		} else {
			parentPath = path.replaceAll(" [0-9]+$", "");	
		}
	}
	private void extractBody() {
		Element excerptContentNode = excerptDoc.getContentNode();
		StringBuilder bodyBuilder;
		Document document = excerptContentNode.getOwnerDocument();
		TransformerFactory transformerFactory = TransformerFactory.newInstance();  
		Transformer transformer = null;
		try {
			transformer = transformerFactory.newTransformer();
			transformer.setOutputProperty(OutputKeys.METHOD, "html"); 
		} catch (TransformerConfigurationException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}              
		
		bodyBuilder = new StringBuilder();
		NodeList excerptContentNodes = excerptContentNode.getChildNodes();
		int i = 0;
		while (excerptContentNodes.getLength() > i) {
			Node child = excerptContentNodes.item(i);
			DOMSource source = new DOMSource(child);
			StringWriter sw = new StringWriter();
			Result streamResult = new StreamResult(sw);
			try {
				transformer.transform(source, streamResult );
			} catch (TransformerException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			bodyBuilder.append(sw.toString());
			i++;

		}
		this.body = bodyBuilder.toString();
	}
}
